// TODO: css remove unnecesarry stuff
// TODO: fetch only once

import React, { useState, useEffect } from 'react'
import fetch from 'unfetch'

import LoadingIndicator from '../components/LoadingIndicator'

import styles from './index.module.css'
import links from '../data/links.json'
import constants from '../constants.json'

export default function Index (props) {
  const [motd, setMotd] = useState('loading...')
  const [news, setNews] = useState(null)

  useEffect(() => {
    console.info('Fetching news.json')
    fetch(`${constants.apiUrl}news.json`, {
      credentials: 'include'
    })
      .then((resp) => {
        return resp.json()
      })
      .then((data) => {
        setNews(data)
      })
  }, [])

  useEffect(() => {
    console.info('Fetching data')
    fetch(`${constants.apiUrl}motd`, {
      credentials: 'include'
    })
      .then((resp) => {
        return resp.text()
      })
      .then((data) => {
        setMotd(data)
      })
  }, [])

  const renderQAItem = (n, key) => {
    return (
      <div key={key} className={styles.itemContainer}>
        <div className={styles.itemNumber}>
          {key} :
        </div>
        <div
          className={styles.question}
          dangerouslySetInnerHTML={{ __html: n.q }}
        />
        <div
          className={styles.answer}
          dangerouslySetInnerHTML={{ __html: n.a }}
        />
      </div>
    )
  }

  const renderNewsItem = (n, key) => {
    return (
      <div key={key} className={styles.itemContainer}>
        <div className={styles.itemNumber}>
          {key} :
        </div>
        <div
          className={styles.newsTitle}
          dangerouslySetInnerHTML={{ __html: n.title }}
        />
        <div
          className={styles.newsBody}
          dangerouslySetInnerHTML={{ __html: n.body }}
        />
      </div>
    )
  }

  const renderNews = () => {
    if (news) {
      let questions = Object.keys(news).map((key, i) => {
        let n = news[key]
        if (n.q) {
          return (
            <div key={key}>
              {renderQAItem(n, key)}
              <hr />
            </div>
          )
        } else {
          return (
            <div key={key}>
              {renderNewsItem(n, key)}
              <hr />
            </div>
          )
        }
      }).reverse()

      return (
        <div className={styles.questionscontainer}>
          {questions}
        </div>
      )
    } else {
      return (
        <LoadingIndicator />
      )
    }
  }

  const renderMotd = () => {
    return (
      <div>
        <div className={styles.motdHeader}>
          MOTD:
        </div>
        <div
          className={styles.motd}
          dangerouslySetInnerHTML={{ __html: motd }}
        />
      </div>
    )
  }

  return (
    <div>
      {renderMotd()}
      <center>
        {Object.keys(links).map((key) => {
          let link = links[key]
          return (
            <span
              className='link'
              key={key}
            >
              <a
                href={link.href}
              >
                <div className={styles.button}>
                  {link.text}
                </div>
              </a>
            </span>
          )
        })}
      </center>
      {renderNews()}
    </div>
  )
}
